import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { queryBuilder } from '@wix/sdk-runtime/query-builder';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixCommentsCategoriesV1CommentsWidget from './comments-categories-v1-comments-widget-widgets.http.js';
// @ts-ignore
import { transformSDKPageURLV2ToRESTPageURLV2 } from '@wix/sdk-runtime/transformations/page-url-v2';
import { transformRESTPageURLV2ToSDKPageURLV2 } from '@wix/sdk-runtime/transformations/page-url-v2';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
export var SortOrder;
(function (SortOrder) {
    SortOrder["ASC"] = "ASC";
    SortOrder["DESC"] = "DESC";
})(SortOrder || (SortOrder = {}));
export var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (WebhookIdentityType = {}));
/**
 * Registers CommentsWidget. Whenever a widget is loaded for the first time or its resourceId changes, it saves the new resource information about the widget
 * @param categoryId - Widget category ID
 * @public
 * @documentationMaturity preview
 * @requiredField categoryId
 * @requiredField options.resourceId
 * @permissionId WIX_COMMENTS.COMMENTS_WIDGET_REGISTER
 * @applicableIdentity VISITOR
 * @fqn wix.comments.categories.v1.CommentsWidgetRegistry.RegisterCommentsWidget
 */
export async function registerCommentsWidget(categoryId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        categoryId: categoryId,
        resourceId: options?.resourceId,
        componentId: options?.componentId,
        dynamicPageTitle: options?.dynamicPageTitle,
        pageId: options?.pageId,
        urlPath: options?.urlPath,
    });
    const reqOpts = ambassadorWixCommentsCategoriesV1CommentsWidget.registerCommentsWidget(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(transformPaths(result.data, [
            {
                transformFn: transformRESTPageURLV2ToSDKPageURLV2,
                paths: [{ path: 'commentsWidget.urlPath' }],
            },
        ]));
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                categoryId: '$[0]',
                resourceId: '$[1].resourceId',
                componentId: '$[1].componentId',
                dynamicPageTitle: '$[1].dynamicPageTitle',
                pageId: '$[1].pageId',
                urlPath: '$[1].urlPath',
            },
            singleArgumentUnchanged: false,
        }, ['categoryId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Returns all registered widget resource ids contained in metaSite
 * @param query - Cursor query
 * @public
 * @documentationMaturity preview
 * @requiredField query
 * @permissionId WIX_COMMENTS.COMMENTS_WIDGET_RESOURCES_QUERY
 * @fqn wix.comments.categories.v1.CommentsWidgetRegistry.QueryCommentsWidgetResources
 */
export async function queryCommentsWidgetResources(query) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({ query: query });
    const reqOpts = ambassadorWixCommentsCategoriesV1CommentsWidget.queryCommentsWidgetResources(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { query: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['query']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Creates a new CommentsWidget
 * @param commentsWidget - CommentsWidget to be created
 * @public
 * @documentationMaturity preview
 * @requiredField commentsWidget
 * @requiredField commentsWidget.categoryId
 * @requiredField commentsWidget.resourceId
 * @permissionId WIX_COMMENTS.COMMENTS_WIDGET_CREATE
 * @returns The created CommentsWidget
 * @fqn wix.comments.categories.v1.CommentsWidgetRegistry.CreateCommentsWidget
 */
export async function createCommentsWidget(commentsWidget) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = transformPaths(renameKeysFromSDKRequestToRESTRequest({ commentsWidget: commentsWidget }), [
        {
            transformFn: transformSDKPageURLV2ToRESTPageURLV2,
            paths: [{ path: 'commentsWidget.urlPath' }],
        },
    ]);
    const reqOpts = ambassadorWixCommentsCategoriesV1CommentsWidget.createCommentsWidget(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(transformPaths(result.data, [
            {
                transformFn: transformRESTPageURLV2ToSDKPageURLV2,
                paths: [{ path: 'commentsWidget.urlPath' }],
            },
        ]))?.commentsWidget;
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { commentsWidget: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['commentsWidget']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Get a CommentsWidget by id
 * @param commentsWidgetId - Id of the CommentsWidget to retrieve
 * @public
 * @documentationMaturity preview
 * @requiredField commentsWidgetId
 * @permissionId WIX_COMMENTS.COMMENTS_WIDGET_READ
 * @applicableIdentity VISITOR
 * @returns The retrieved CommentsWidget
 * @fqn wix.comments.categories.v1.CommentsWidgetRegistry.GetCommentsWidget
 */
export async function getCommentsWidget(commentsWidgetId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        commentsWidgetId: commentsWidgetId,
    });
    const reqOpts = ambassadorWixCommentsCategoriesV1CommentsWidget.getCommentsWidget(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(transformPaths(result.data, [
            {
                transformFn: transformRESTPageURLV2ToSDKPageURLV2,
                paths: [{ path: 'commentsWidget.urlPath' }],
            },
        ]))?.commentsWidget;
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { commentsWidgetId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['commentsWidgetId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Update CommentsWidget, supports partial update
 * Pass the latest `revision` for a successful update
 * @param _id - CommentsWidget ID
 * @public
 * @documentationMaturity preview
 * @requiredField _id
 * @requiredField commentsWidget
 * @requiredField commentsWidget.revision
 * @permissionId WIX_COMMENTS.COMMENTS_WIDGET_EDIT
 * @returns The updated CommentsWidget
 * @fqn wix.comments.categories.v1.CommentsWidgetRegistry.UpdateCommentsWidget
 */
export async function updateCommentsWidget(_id, commentsWidget) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = transformPaths(renameKeysFromSDKRequestToRESTRequest({
        commentsWidget: { ...commentsWidget, id: _id },
    }), [
        {
            transformFn: transformSDKPageURLV2ToRESTPageURLV2,
            paths: [{ path: 'commentsWidget.urlPath' }],
        },
    ]);
    const reqOpts = ambassadorWixCommentsCategoriesV1CommentsWidget.updateCommentsWidget(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(transformPaths(result.data, [
            {
                transformFn: transformRESTPageURLV2ToSDKPageURLV2,
                paths: [{ path: 'commentsWidget.urlPath' }],
            },
        ]))?.commentsWidget;
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: { commentsWidget: '$[1]' },
            explicitPathsToArguments: { 'commentsWidget.id': '$[0]' },
            singleArgumentUnchanged: false,
        }, ['_id', 'commentsWidget']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Delete a CommentsWidget
 * @param commentsWidgetId - Id of the CommentsWidget to delete
 * @public
 * @documentationMaturity preview
 * @requiredField commentsWidgetId
 * @permissionId WIX_COMMENTS.COMMENTS_WIDGET_DELETE
 * @fqn wix.comments.categories.v1.CommentsWidgetRegistry.DeleteCommentsWidget
 */
export async function deleteCommentsWidget(commentsWidgetId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        commentsWidgetId: commentsWidgetId,
        revision: options?.revision,
    });
    const reqOpts = ambassadorWixCommentsCategoriesV1CommentsWidget.deleteCommentsWidget(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                commentsWidgetId: '$[0]',
                revision: '$[1].revision',
            },
            singleArgumentUnchanged: false,
        }, ['commentsWidgetId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Query CommentsWidgets using [WQL - Wix Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language)
 * @public
 * @documentationMaturity preview
 * @permissionId WIX_COMMENTS.COMMENTS_WIDGET_QUERY
 * @applicableIdentity VISITOR
 * @fqn wix.comments.categories.v1.CommentsWidgetRegistry.QueryCommentsWidget
 */
export function queryCommentsWidget() {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[0];
    return queryBuilder({
        func: async (payload) => {
            const reqOpts = ambassadorWixCommentsCategoriesV1CommentsWidget.queryCommentsWidget(payload);
            sideEffects?.onSiteCall?.();
            try {
                const result = await httpClient.request(reqOpts);
                sideEffects?.onSuccess?.(result);
                return result;
            }
            catch (err) {
                sideEffects?.onError?.(err);
                throw err;
            }
        },
        requestTransformer: (query) => {
            const args = [query, {}];
            return renameKeysFromSDKRequestToRESTRequest({
                ...args?.[1],
                query: args?.[0],
            });
        },
        responseTransformer: ({ data, }) => {
            const transformedData = renameKeysFromRESTResponseToSDKResponse(transformPaths(data, [
                {
                    transformFn: transformRESTPageURLV2ToSDKPageURLV2,
                    paths: [{ path: 'commentsWidgets.urlPath' }],
                },
            ]));
            return {
                items: transformedData?.commentsWidgets,
                pagingMetadata: transformedData?.metadata,
            };
        },
        errorTransformer: (err) => {
            const transformedError = sdkTransformError(err, {
                spreadPathsToArguments: {},
                explicitPathsToArguments: { query: '$[0]' },
                singleArgumentUnchanged: false,
            });
            throw transformedError;
        },
        pagingMethod: 'CURSOR',
        transformationPaths: {},
    });
}
//# sourceMappingURL=comments-categories-v1-comments-widget-widgets.universal.js.map