import { EventDefinition, HttpClient } from '@wix/sdk-types';
import { CommentsWidget, CommentsWidgetCreatedEnvelope, CommentsWidgetDeletedEnvelope, CommentsWidgetUpdatedEnvelope, CommentsWidgetsQueryBuilder, CursorQuery, DeleteCommentsWidgetOptions, QueryCommentsWidgetResourcesResponse, RegisterCommentsWidgetOptions, RegisterCommentsWidgetResponse, UpdateCommentsWidget } from './comments-categories-v1-comments-widget-widgets.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function registerCommentsWidget(httpClient: HttpClient): RegisterCommentsWidgetSignature;
interface RegisterCommentsWidgetSignature {
    /**
     * Registers CommentsWidget. Whenever a widget is loaded for the first time or its resourceId changes, it saves the new resource information about the widget
     * @param - Widget category ID
     */
    (categoryId: string, options?: RegisterCommentsWidgetOptions | undefined): Promise<RegisterCommentsWidgetResponse>;
}
export declare function queryCommentsWidgetResources(httpClient: HttpClient): QueryCommentsWidgetResourcesSignature;
interface QueryCommentsWidgetResourcesSignature {
    /**
     * Returns all registered widget resource ids contained in metaSite
     * @param - Cursor query
     */
    (query: CursorQuery): Promise<QueryCommentsWidgetResourcesResponse>;
}
export declare function createCommentsWidget(httpClient: HttpClient): CreateCommentsWidgetSignature;
interface CreateCommentsWidgetSignature {
    /**
     * Creates a new CommentsWidget
     * @param - CommentsWidget to be created
     * @returns The created CommentsWidget
     */
    (commentsWidget: CommentsWidget): Promise<CommentsWidget>;
}
export declare function getCommentsWidget(httpClient: HttpClient): GetCommentsWidgetSignature;
interface GetCommentsWidgetSignature {
    /**
     * Get a CommentsWidget by id
     * @param - Id of the CommentsWidget to retrieve
     * @returns The retrieved CommentsWidget
     */
    (commentsWidgetId: string): Promise<CommentsWidget>;
}
export declare function updateCommentsWidget(httpClient: HttpClient): UpdateCommentsWidgetSignature;
interface UpdateCommentsWidgetSignature {
    /**
     * Update CommentsWidget, supports partial update
     * Pass the latest `revision` for a successful update
     * @param - CommentsWidget ID
     * @returns The updated CommentsWidget
     */
    (_id: string, commentsWidget: UpdateCommentsWidget): Promise<CommentsWidget>;
}
export declare function deleteCommentsWidget(httpClient: HttpClient): DeleteCommentsWidgetSignature;
interface DeleteCommentsWidgetSignature {
    /**
     * Delete a CommentsWidget
     * @param - Id of the CommentsWidget to delete
     */
    (commentsWidgetId: string, options?: DeleteCommentsWidgetOptions | undefined): Promise<void>;
}
export declare function queryCommentsWidget(httpClient: HttpClient): QueryCommentsWidgetSignature;
interface QueryCommentsWidgetSignature {
    /**
     * Query CommentsWidgets using [WQL - Wix Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language)
     */
    (): CommentsWidgetsQueryBuilder;
}
export declare const onCommentsWidgetCreated: EventDefinition<CommentsWidgetCreatedEnvelope, "wix.comments.categories.v1.comments_widget_created">;
export declare const onCommentsWidgetDeleted: EventDefinition<CommentsWidgetDeletedEnvelope, "wix.comments.categories.v1.comments_widget_deleted">;
export declare const onCommentsWidgetUpdated: EventDefinition<CommentsWidgetUpdatedEnvelope, "wix.comments.categories.v1.comments_widget_updated">;
export { ActionEvent, BaseEventMetadata, CommentsWidget, CommentsWidgetCreatedEnvelope, CommentsWidgetDeletedEnvelope, CommentsWidgetUpdatedEnvelope, CommentsWidgetsQueryBuilder, CommentsWidgetsQueryResult, CreateCommentsWidgetRequest, CreateCommentsWidgetResponse, CursorPaging, CursorPagingMetadata, CursorQuery, CursorQueryPagingMethodOneOf, Cursors, DeleteCommentsWidgetOptions, DeleteCommentsWidgetRequest, DeleteCommentsWidgetResponse, DomainEvent, DomainEventBodyOneOf, Empty, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventMetadata, GetCommentsWidgetRequest, GetCommentsWidgetResponse, IdentificationData, IdentificationDataIdOneOf, MessageEnvelope, Paging, PagingMetadataV2, QueryCommentsWidgetRequest, QueryCommentsWidgetResourcesRequest, QueryCommentsWidgetResourcesResponse, QueryCommentsWidgetResponse, QueryV2, QueryV2PagingMethodOneOf, RegisterCommentsWidgetOptions, RegisterCommentsWidgetRequest, RegisterCommentsWidgetResponse, RestoreInfo, SortOrder, Sorting, UpdateCommentsWidget, UpdateCommentsWidgetRequest, UpdateCommentsWidgetResponse, WebhookIdentityType, } from './comments-categories-v1-comments-widget-widgets.universal.js';
