"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.queryCommentsWidget = exports.deleteCommentsWidget = exports.updateCommentsWidget = exports.getCommentsWidget = exports.createCommentsWidget = exports.queryCommentsWidgetResources = exports.registerCommentsWidget = exports.WebhookIdentityType = exports.SortOrder = void 0;
const transform_error_1 = require("@wix/sdk-runtime/transform-error");
const query_builder_1 = require("@wix/sdk-runtime/query-builder");
const rename_all_nested_keys_1 = require("@wix/sdk-runtime/rename-all-nested-keys");
const ambassadorWixCommentsCategoriesV1CommentsWidget = __importStar(require("./comments-categories-v1-comments-widget-widgets.http.js"));
// @ts-ignore
const page_url_v2_1 = require("@wix/sdk-runtime/transformations/page-url-v2");
const page_url_v2_2 = require("@wix/sdk-runtime/transformations/page-url-v2");
const transform_paths_1 = require("@wix/sdk-runtime/transformations/transform-paths");
var SortOrder;
(function (SortOrder) {
    SortOrder["ASC"] = "ASC";
    SortOrder["DESC"] = "DESC";
})(SortOrder || (exports.SortOrder = SortOrder = {}));
var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (exports.WebhookIdentityType = WebhookIdentityType = {}));
/**
 * Registers CommentsWidget. Whenever a widget is loaded for the first time or its resourceId changes, it saves the new resource information about the widget
 * @param categoryId - Widget category ID
 * @public
 * @documentationMaturity preview
 * @requiredField categoryId
 * @requiredField options.resourceId
 * @permissionId WIX_COMMENTS.COMMENTS_WIDGET_REGISTER
 * @applicableIdentity VISITOR
 * @fqn wix.comments.categories.v1.CommentsWidgetRegistry.RegisterCommentsWidget
 */
async function registerCommentsWidget(categoryId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        categoryId: categoryId,
        resourceId: options?.resourceId,
        componentId: options?.componentId,
        dynamicPageTitle: options?.dynamicPageTitle,
        pageId: options?.pageId,
        urlPath: options?.urlPath,
    });
    const reqOpts = ambassadorWixCommentsCategoriesV1CommentsWidget.registerCommentsWidget(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)((0, transform_paths_1.transformPaths)(result.data, [
            {
                transformFn: page_url_v2_2.transformRESTPageURLV2ToSDKPageURLV2,
                paths: [{ path: 'commentsWidget.urlPath' }],
            },
        ]));
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                categoryId: '$[0]',
                resourceId: '$[1].resourceId',
                componentId: '$[1].componentId',
                dynamicPageTitle: '$[1].dynamicPageTitle',
                pageId: '$[1].pageId',
                urlPath: '$[1].urlPath',
            },
            singleArgumentUnchanged: false,
        }, ['categoryId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.registerCommentsWidget = registerCommentsWidget;
/**
 * Returns all registered widget resource ids contained in metaSite
 * @param query - Cursor query
 * @public
 * @documentationMaturity preview
 * @requiredField query
 * @permissionId WIX_COMMENTS.COMMENTS_WIDGET_RESOURCES_QUERY
 * @fqn wix.comments.categories.v1.CommentsWidgetRegistry.QueryCommentsWidgetResources
 */
async function queryCommentsWidgetResources(query) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({ query: query });
    const reqOpts = ambassadorWixCommentsCategoriesV1CommentsWidget.queryCommentsWidgetResources(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { query: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['query']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.queryCommentsWidgetResources = queryCommentsWidgetResources;
/**
 * Creates a new CommentsWidget
 * @param commentsWidget - CommentsWidget to be created
 * @public
 * @documentationMaturity preview
 * @requiredField commentsWidget
 * @requiredField commentsWidget.categoryId
 * @requiredField commentsWidget.resourceId
 * @permissionId WIX_COMMENTS.COMMENTS_WIDGET_CREATE
 * @returns The created CommentsWidget
 * @fqn wix.comments.categories.v1.CommentsWidgetRegistry.CreateCommentsWidget
 */
async function createCommentsWidget(commentsWidget) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, transform_paths_1.transformPaths)((0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({ commentsWidget: commentsWidget }), [
        {
            transformFn: page_url_v2_1.transformSDKPageURLV2ToRESTPageURLV2,
            paths: [{ path: 'commentsWidget.urlPath' }],
        },
    ]);
    const reqOpts = ambassadorWixCommentsCategoriesV1CommentsWidget.createCommentsWidget(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)((0, transform_paths_1.transformPaths)(result.data, [
            {
                transformFn: page_url_v2_2.transformRESTPageURLV2ToSDKPageURLV2,
                paths: [{ path: 'commentsWidget.urlPath' }],
            },
        ]))?.commentsWidget;
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { commentsWidget: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['commentsWidget']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.createCommentsWidget = createCommentsWidget;
/**
 * Get a CommentsWidget by id
 * @param commentsWidgetId - Id of the CommentsWidget to retrieve
 * @public
 * @documentationMaturity preview
 * @requiredField commentsWidgetId
 * @permissionId WIX_COMMENTS.COMMENTS_WIDGET_READ
 * @applicableIdentity VISITOR
 * @returns The retrieved CommentsWidget
 * @fqn wix.comments.categories.v1.CommentsWidgetRegistry.GetCommentsWidget
 */
async function getCommentsWidget(commentsWidgetId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        commentsWidgetId: commentsWidgetId,
    });
    const reqOpts = ambassadorWixCommentsCategoriesV1CommentsWidget.getCommentsWidget(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)((0, transform_paths_1.transformPaths)(result.data, [
            {
                transformFn: page_url_v2_2.transformRESTPageURLV2ToSDKPageURLV2,
                paths: [{ path: 'commentsWidget.urlPath' }],
            },
        ]))?.commentsWidget;
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { commentsWidgetId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['commentsWidgetId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.getCommentsWidget = getCommentsWidget;
/**
 * Update CommentsWidget, supports partial update
 * Pass the latest `revision` for a successful update
 * @param _id - CommentsWidget ID
 * @public
 * @documentationMaturity preview
 * @requiredField _id
 * @requiredField commentsWidget
 * @requiredField commentsWidget.revision
 * @permissionId WIX_COMMENTS.COMMENTS_WIDGET_EDIT
 * @returns The updated CommentsWidget
 * @fqn wix.comments.categories.v1.CommentsWidgetRegistry.UpdateCommentsWidget
 */
async function updateCommentsWidget(_id, commentsWidget) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, transform_paths_1.transformPaths)((0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        commentsWidget: { ...commentsWidget, id: _id },
    }), [
        {
            transformFn: page_url_v2_1.transformSDKPageURLV2ToRESTPageURLV2,
            paths: [{ path: 'commentsWidget.urlPath' }],
        },
    ]);
    const reqOpts = ambassadorWixCommentsCategoriesV1CommentsWidget.updateCommentsWidget(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)((0, transform_paths_1.transformPaths)(result.data, [
            {
                transformFn: page_url_v2_2.transformRESTPageURLV2ToSDKPageURLV2,
                paths: [{ path: 'commentsWidget.urlPath' }],
            },
        ]))?.commentsWidget;
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: { commentsWidget: '$[1]' },
            explicitPathsToArguments: { 'commentsWidget.id': '$[0]' },
            singleArgumentUnchanged: false,
        }, ['_id', 'commentsWidget']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.updateCommentsWidget = updateCommentsWidget;
/**
 * Delete a CommentsWidget
 * @param commentsWidgetId - Id of the CommentsWidget to delete
 * @public
 * @documentationMaturity preview
 * @requiredField commentsWidgetId
 * @permissionId WIX_COMMENTS.COMMENTS_WIDGET_DELETE
 * @fqn wix.comments.categories.v1.CommentsWidgetRegistry.DeleteCommentsWidget
 */
async function deleteCommentsWidget(commentsWidgetId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        commentsWidgetId: commentsWidgetId,
        revision: options?.revision,
    });
    const reqOpts = ambassadorWixCommentsCategoriesV1CommentsWidget.deleteCommentsWidget(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                commentsWidgetId: '$[0]',
                revision: '$[1].revision',
            },
            singleArgumentUnchanged: false,
        }, ['commentsWidgetId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.deleteCommentsWidget = deleteCommentsWidget;
/**
 * Query CommentsWidgets using [WQL - Wix Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language)
 * @public
 * @documentationMaturity preview
 * @permissionId WIX_COMMENTS.COMMENTS_WIDGET_QUERY
 * @applicableIdentity VISITOR
 * @fqn wix.comments.categories.v1.CommentsWidgetRegistry.QueryCommentsWidget
 */
function queryCommentsWidget() {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[0];
    return (0, query_builder_1.queryBuilder)({
        func: async (payload) => {
            const reqOpts = ambassadorWixCommentsCategoriesV1CommentsWidget.queryCommentsWidget(payload);
            sideEffects?.onSiteCall?.();
            try {
                const result = await httpClient.request(reqOpts);
                sideEffects?.onSuccess?.(result);
                return result;
            }
            catch (err) {
                sideEffects?.onError?.(err);
                throw err;
            }
        },
        requestTransformer: (query) => {
            const args = [query, {}];
            return (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
                ...args?.[1],
                query: args?.[0],
            });
        },
        responseTransformer: ({ data, }) => {
            const transformedData = (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)((0, transform_paths_1.transformPaths)(data, [
                {
                    transformFn: page_url_v2_2.transformRESTPageURLV2ToSDKPageURLV2,
                    paths: [{ path: 'commentsWidgets.urlPath' }],
                },
            ]));
            return {
                items: transformedData?.commentsWidgets,
                pagingMetadata: transformedData?.metadata,
            };
        },
        errorTransformer: (err) => {
            const transformedError = (0, transform_error_1.transformError)(err, {
                spreadPathsToArguments: {},
                explicitPathsToArguments: { query: '$[0]' },
                singleArgumentUnchanged: false,
            });
            throw transformedError;
        },
        pagingMethod: 'CURSOR',
        transformationPaths: {},
    });
}
exports.queryCommentsWidget = queryCommentsWidget;
//# sourceMappingURL=comments-categories-v1-comments-widget-widgets.universal.js.map