import { renameKeysFromRESTResponseToSDKResponse } from '@wix/sdk-runtime/rename-all-nested-keys';
import { transformRESTPageURLV2ToSDKPageURLV2 } from '@wix/sdk-runtime/transformations/page-url-v2';
import { transformRESTTimestampToSDKTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { EventDefinition } from '@wix/sdk-types';
import { createCommentsWidget as universalCreateCommentsWidget, deleteCommentsWidget as universalDeleteCommentsWidget, getCommentsWidget as universalGetCommentsWidget, queryCommentsWidget as universalQueryCommentsWidget, queryCommentsWidgetResources as universalQueryCommentsWidgetResources, registerCommentsWidget as universalRegisterCommentsWidget, updateCommentsWidget as universalUpdateCommentsWidget, } from './comments-categories-v1-comments-widget-widgets.universal.js';
export const __metadata = { PACKAGE_NAME: '@wix/comments' };
export function registerCommentsWidget(httpClient) {
    return (categoryId, options) => universalRegisterCommentsWidget(categoryId, options, 
    // @ts-ignore
    { httpClient });
}
export function queryCommentsWidgetResources(httpClient) {
    return (query) => universalQueryCommentsWidgetResources(query, 
    // @ts-ignore
    { httpClient });
}
export function createCommentsWidget(httpClient) {
    return (commentsWidget) => universalCreateCommentsWidget(commentsWidget, 
    // @ts-ignore
    { httpClient });
}
export function getCommentsWidget(httpClient) {
    return (commentsWidgetId) => universalGetCommentsWidget(commentsWidgetId, 
    // @ts-ignore
    { httpClient });
}
export function updateCommentsWidget(httpClient) {
    return (_id, commentsWidget) => universalUpdateCommentsWidget(_id, commentsWidget, 
    // @ts-ignore
    { httpClient });
}
export function deleteCommentsWidget(httpClient) {
    return (commentsWidgetId, options) => universalDeleteCommentsWidget(commentsWidgetId, options, 
    // @ts-ignore
    { httpClient });
}
export function queryCommentsWidget(httpClient) {
    return () => universalQueryCommentsWidget(
    // @ts-ignore
    { httpClient });
}
export const onCommentsWidgetCreated = EventDefinition('wix.comments.categories.v1.comments_widget_created', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTPageURLV2ToSDKPageURLV2,
        paths: [{ path: 'entity.urlPath' }],
    },
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'entity.createdDate' },
            { path: 'entity.updatedDate' },
            { path: 'metadata.eventTime' },
        ],
    },
])))();
export const onCommentsWidgetDeleted = EventDefinition('wix.comments.categories.v1.comments_widget_deleted', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTPageURLV2ToSDKPageURLV2,
        paths: [{ path: 'undefined.urlPath' }],
    },
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'undefined.createdDate' },
            { path: 'undefined.updatedDate' },
            { path: 'metadata.eventTime' },
        ],
    },
])))();
export const onCommentsWidgetUpdated = EventDefinition('wix.comments.categories.v1.comments_widget_updated', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTPageURLV2ToSDKPageURLV2,
        paths: [{ path: 'entity.urlPath' }],
    },
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'entity.createdDate' },
            { path: 'entity.updatedDate' },
            { path: 'metadata.eventTime' },
        ],
    },
])))();
export { SortOrder, WebhookIdentityType, } from './comments-categories-v1-comments-widget-widgets.universal.js';
//# sourceMappingURL=comments-categories-v1-comments-widget-widgets.public.js.map